summaryrefslogtreecommitdiffstats
path: root/src/entryitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/entryitem.h')
-rw-r--r--src/entryitem.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/entryitem.h b/src/entryitem.h
index 4c99207..667f12e 100644
--- a/src/entryitem.h
+++ b/src/entryitem.h
@@ -37,19 +37,19 @@ public:
* This constructor is for items which are direct tqchildren of a ListView object,
* which is just the @ref DetailedListView.
*
* @param tqparent A pointer to the tqparent
* @param entry A pointer to the entry to which the item refers
*/
- EntryItem(GUI::ListView* tqparent, Data::EntryPtr entry);
+ EntryItem(GUI::ListView* parent, Data::EntryPtr entry);
/**
* This constructor is for items which have other KListViewItems as parents. It
* initializes the text in the first column, as well.
*
* @param tqparent A pointer to the tqparent
* @param text The text in the first column
* @param entry A pointer to the entry to which the item refers
*/
- EntryItem(GUI::CountedItem* tqparent, Data::EntryPtr entry);
+ EntryItem(GUI::CountedItem* parent, Data::EntryPtr entry);
virtual bool isEntryItem() const { return true; }
@@ -73,7 +73,7 @@ public:
private:
Data::EntryPtr m_entry;
- // if the tqparent is a DetailedListView
+ // if the parent is a DetailedListView
// this way, I don't have to call listView()->isA("Tellico::DetailedListView") every time
// when I want to do funky comparisons
bool m_isDetailedList : 1;
@@ -37,19 +37,19 @@ public:
* which is just the @ref DetailedListView.
*
- * @param tqparent A pointer to the tqparent
+ * @param parent A pointer to the parent
* @param entry A pointer to the entry to which the item refers
*/
@@ -37,19 +37,19 @@ public:
* initializes the text in the first column, as well.
*
- * @param tqparent A pointer to the tqparent
+ * @param parent A pointer to the parent
* @param text The text in the first column
* @param entry A pointer to the entry to which the item refers